==> bow-ui-1.1-sources.jar: org/chorem/bow/BowUserHelper.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public  class BowUserHelper {

    /**
     * BowUserHelper :
     * utility class all provided methods are accessible the static way
     */

    private BowUserHelper() {// empty
}

    /**
     * getPermanentToken :
     * @param wikitty 
     * @return String 
     */

    public static String getPermanentToken(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN);
        return value;
}

    /**
     * setPermanentToken :
     * @param wikitty 
     * @param permanentToken 
     * @return String 
     */

    public static String setPermanentToken(Wikitty wikitty, String permanentToken) {
        String oldValue = getPermanentToken(wikitty);
        wikitty.setField(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN, permanentToken);
        return oldValue;
}

    /**
     * equals :
     * @param w1 
     * @param w2 
     * @return boolean 
     */

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN);
            Object f2 = w2.getFieldAsObject(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * isExtension :
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return boolean 
     */

    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * hasExtension :
     * check if wikitty has current extension
     * @param wikitty 
     * @return boolean 
     */

    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(BowUser.EXT_BOWUSER);
}

    /**
     * addExtension :
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */

    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowUserAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}


} //BowUserHelper

==> bow-ui-1.4.1-sources.jar: org/chorem/bow/BowUserHelper.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class BowUserHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private BowUserHelper() {// empty
}

    public static String getPermanentToken(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN);
        return value;
}

    public static String setPermanentToken(Wikitty wikitty, String permanentToken) {
        String oldValue = getPermanentToken(wikitty);
        wikitty.setField(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN, permanentToken);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN);
            Object f2 = w2.getFieldAsObject(BowUser.EXT_BOWUSER, BowUser.FIELD_BOWUSER_PERMANENTTOKEN);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(BowUser.EXT_BOWUSER);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowUserAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * supprime les extensions de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void removeExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowUserAbstract.extensions) {
            wikitty.removeExtension(ext.getName());
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(BowUser.EXT_BOWUSER);
}

} //BowUserHelper
